@@ -1,6 +1,6 @@
 import numpy.matlib
 import pandas as pd
-from pytrad.score.ScoreUtils import *
+from pytrad.utils.ScoreUtils import *
 import math
 
 
